/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#ifndef GEODE_THINCLIENTPOOLSTICKYHADM_H_
#define GEODE_THINCLIENTPOOLSTICKYHADM_H_

#include "ThinClientPoolHADM.hpp"

namespace apache {
namespace geode {
namespace client {

class ThinClientPoolStickyHADM : public ThinClientPoolHADM {
 public:
  ThinClientPoolStickyHADM(const char* name,
                           std::shared_ptr<PoolAttributes> poolAttrs,
                           TcrConnectionManager& connManager)
      : ThinClientPoolHADM(name, poolAttrs, connManager) {
    m_sticky = true;
  }
  ~ThinClientPoolStickyHADM() override = default;
};

}  // namespace client
}  // namespace geode
}  // namespace apache

#endif  // GEODE_THINCLIENTPOOLSTICKYHADM_H_
